@@ -1,11 +1,11 @@
 var group__spa__node =
 [
-    [ "node/command.h", "node_2command_8h.html", null ],
-    [ "node/event.h", "node_2event_8h.html", null ],
+    [ "command.h", "node_2command_8h.html", null ],
+    [ "event.h", "node_2event_8h.html", null ],
     [ "io.h", "io_8h.html", null ],
-    [ "spa/include/spa/node/keys.h", "spa_2include_2spa_2node_2keys_8h.html", null ],
-    [ "spa/include/spa/node/node.h", "spa_2include_2spa_2node_2node_8h.html", null ],
-    [ "node/type-info.h", "node_2type-info_8h.html", null ],
+    [ "keys.h", "spa_2include_2spa_2node_2keys_8h.html", null ],
+    [ "node.h", "spa_2include_2spa_2node_2node_8h.html", null ],
+    [ "type-info.h", "node_2type-info_8h.html", null ],
     [ "spa_io_buffers", "structspa__io__buffers.html", [
       [ "status", "structspa__io__buffers.html#a1364df7bc201533525e5a4fa54f444fe", null ],
       [ "buffer_id", "structspa__io__buffers.html#aadfe10a114c998d88137450877d8326b", null ]
@@ -33,7 +33,8 @@ var group__spa__node =
       [ "target_rate", "structspa__io__clock.html#a02274245ac560717fc5c06ddc66553ff", null ],
       [ "target_duration", "structspa__io__clock.html#ad5f6c0254efd87a20ca5807b577d3473", null ],
       [ "target_seq", "structspa__io__clock.html#af91526e984d8c9453e8b98c12dd1f500", null ],
-      [ "padding", "structspa__io__clock.html#ade3b0ef4306272d9a83a361ac3312cad", null ]
+      [ "padding", "structspa__io__clock.html#add07660ad1ad6f6951596c5a0422cd9b", null ],
+      [ "xrun", "structspa__io__clock.html#a3dc77892eea443b66c01d2acc91acaeb", null ]
     ] ],
     [ "spa_io_video_size", "structspa__io__video__size.html", [
       [ "flags", "structspa__io__video__size.html#ab8f1361af870dd5de789b63b687a22ce", null ],
@@ -179,6 +180,7 @@ var group__spa__node =
     [ "SPA_IO_POSITION_MAX_SEGMENTS", "group__spa__node.html#ga9ac58e570992a64d125bd9f91985996f", null ],
     [ "SPA_IO_RATE_MATCH_FLAG_ACTIVE", "group__spa__node.html#ga920474a132a02e42e1a6269abffca423", null ],
     [ "SPA_KEY_NODE_NAME", "group__spa__node.html#ga7e9282d67981bd0d7cc34a8501b93ab2", null ],
+    [ "SPA_KEY_NODE_DESCRIPTION", "group__spa__node.html#ga9d50627a49b34986d74524ca4238c228", null ],
     [ "SPA_KEY_NODE_LATENCY", "group__spa__node.html#ga8a3e4b89dbe6949139b02898cd5ba23a", null ],
     [ "SPA_KEY_NODE_MAX_LATENCY", "group__spa__node.html#gadcb55c17c2f80d36f159bc763fd309e7", null ],
     [ "SPA_KEY_NODE_DRIVER", "group__spa__node.html#gae05de298da37b1a5d644aa87cf2a5220", null ],
