@@ -1,5 +1,24 @@
 var NAVTREEINDEX8 =
 {
+"group__spa__hooks.html#gacb30a0a53954eed2af8041a1882eef15":[10,8,8,4,14],
+"group__spa__hooks.html#gacbc74f9ceab3dc7c5d6d8c3eca6a41e5":[10,8,8,4,12],
+"group__spa__hooks.html#gadb7d27ebaa8d5997c5420910de1db773":[10,8,8,4,4],
+"group__spa__hooks.html#gaddde6a682396fb0125849ed615c8d0c5":[10,8,8,4,7],
+"group__spa__hooks.html#gae70f84c0eb2bae8f5d08eb694969dd40":[10,8,8,4,15],
+"group__spa__i18n.html":[10,8,9,2],
+"group__spa__i18n.html#gaa4c021574498780906bcc3f2958cc23f":[10,8,9,2,7],
+"group__spa__i18n.html#gab6c7211ad9795cf4c1c55487c165a555":[10,8,9,2,4],
+"group__spa__i18n.html#gacc03db6ab5181108527ca45e7674b235":[10,8,9,2,3],
+"group__spa__i18n.html#gaf3aa0f8921abf9d572c9fde4a9d0825d":[10,8,9,2,5],
+"group__spa__i18n.html#gafe48fd94d55ba3db8f10fb1550ec79c8":[10,8,9,2,6],
+"group__spa__interfaces.html":[10,8,8,5],
+"group__spa__interfaces.html#ga0b43b5a0ee8aa8f305d0c9971716e5b0":[10,8,8,5,17],
+"group__spa__interfaces.html#ga12d9c46094ccfe8448e2d592cc8f457b":[10,8,8,5,18],
+"group__spa__interfaces.html#ga1566a7843972b177af627e6e16b86c26":[10,8,8,5,13],
+"group__spa__interfaces.html#ga1facc1b12f5dfb7e3362e9f1a6d3cb6c":[10,8,8,5,15],
+"group__spa__interfaces.html#ga333235e7b2636c920cfa766481e59729":[10,8,8,5,16],
+"group__spa__interfaces.html#ga48dc1c688fd324d08a3eed9684abf41a":[10,8,8,5,8],
+"group__spa__interfaces.html#ga5f51d2f3b4df5eb44fa6163ba3958f5d":[10,8,8,5,7],
 "group__spa__interfaces.html#ga6492da0e834e92dbbcef7dd3026ce04f":[10,8,8,5,10],
 "group__spa__interfaces.html#ga7cd31fca0faa447261fb4425d8036bb5":[10,8,8,5,5],
 "group__spa__interfaces.html#ga7eadf4e30be75d856d81c9b0d818b0e1":[10,8,8,5,3],
@@ -230,24 +249,5 @@ var NAVTREEINDEX8 =
 "group__spa__loop.html#gaf67b95b170f125ee503fec3640b727ca":[10,8,9,4,44],
 "group__spa__loop.html#gafdc6876cd766fafc297841accedcd105":[10,8,9,4,34],
 "group__spa__loop.html#gaffe08d7788d04fa44c44fda7ab3649bb":[10,8,9,4,30],
-"group__spa__names.html":[10,8,8,8],
-"group__spa__names.html#ga010bfd1f2c50f4927df733f5f13e5690":[10,8,8,8,23],
-"group__spa__names.html#ga0847db019357b78b2fda5d40da8f2d39":[10,8,8,8,3],
-"group__spa__names.html#ga0b43d949e15c4f27d3e3f0d04311ef85":[10,8,8,8,14],
-"group__spa__names.html#ga11c2cbfdfb9e3c5c6f2567527be11f02":[10,8,8,8,51],
-"group__spa__names.html#ga140a10dbb30ba2bbd75eb1612a79bcf5":[10,8,8,8,49],
-"group__spa__names.html#ga16aaa669b52a214c66192b76d8103078":[10,8,8,8,4],
-"group__spa__names.html#ga191088dbac1ee56122ceb215f16604d5":[10,8,8,8,53],
-"group__spa__names.html#ga1abe79976239b87710c2e50bf5202a3b":[10,8,8,8,17],
-"group__spa__names.html#ga1c5ec5f41159cc0037ac36f61496e7e2":[10,8,8,8,5],
-"group__spa__names.html#ga26e449f9f86ba68d8b30c5b74f5b86da":[10,8,8,8,2],
-"group__spa__names.html#ga2dfd6b7bede9d0057cc3d926a6f6daea":[10,8,8,8,29],
-"group__spa__names.html#ga35b295254f73d500d2e10914b50efcf8":[10,8,8,8,15],
-"group__spa__names.html#ga38307a0857ead4864fd8fd8b306d2779":[10,8,8,8,40],
-"group__spa__names.html#ga396be5fd0d0d7f77895bae3df9661c5c":[10,8,8,8,10],
-"group__spa__names.html#ga3b2743930157d57db10d9f9761b2ad5e":[10,8,8,8,18],
-"group__spa__names.html#ga3f4910b31a7f9c759e72b1c1797951a9":[10,8,8,8,24],
-"group__spa__names.html#ga419f7550308d9b74cf2423772b049d14":[10,8,8,8,1],
-"group__spa__names.html#ga45fd55853ff79716c7d4dfaa4b004449":[10,8,8,8,37],
-"group__spa__names.html#ga4634945f76f5e790fedccc5431343d69":[10,8,8,8,47]
+"group__spa__names.html":[10,8,8,8]
 };
